@@ -8,8 +8,8 @@
 #' @param stop_on_failure Throw an error instead of returning
 #' \code{\link{FALSE}} if the environment variable is not set or cannot be
 #' converted to boolean.
-#' @family test helpers.
-#' @family operating system functions.
+#' @family test helpers
+#' @family operating system functions
 #' @return The value the environment variable is set to, converted to boolean.
 #' \code{\link{FALSE}} if the environment variable is not set or cannot be
 #' converted to boolean. But see \strong{Arguments}: \emph{stop_on_failure}.
@@ -45,16 +45,18 @@ get_boolean_envvar <- function(x, stop_on_failure = FALSE) {
     return(r)
 }
 
-#' Is the Machine Running the Current \R Process Owned by FVAFRCU?
+#' Is the Machine Running the Current '\R' Process Owned by FVAFRCU?
 #'
 #' Is the machine running the current \R process known to me?
 #' @template return_boolean
-#' @family test helpers.
-#' @family logical helpers.
+#' @param type An optional selection.
+#' @family test helpers
+#' @family logical helpers
 #' @export
 #' @examples
 #' is_running_on_fvafrcu_machines()
-is_running_on_fvafrcu_machines <- function() {
+is_running_on_fvafrcu_machines <- function(type = c("any", "cu", "bwi",
+                                                    "fvafr")) {
     sys_info <- Sys.info()
     h <- sys_info[["nodename"]] %in% c("h6", "h7") &&
         .Platform[["OS.type"]] == "unix" &&
@@ -63,10 +65,18 @@ is_running_on_fvafrcu_machines <- function() {
         .Platform[["OS.type"]] == "unix" &&
         sys_info[["effective_user"]] %in%
         c("dominik.cullmann", "dominik", "nik")
-    w <- (grepl("^FVAFR-PC.*$", sys_info[["nodename"]]) ||
-          grepl("^L-FVAFR-NB84223$", sys_info[["nodename"]])
-      ) && is_windows() && sys_info[["effective_user"]] == "dominik.cullmann"
-    r <-  h || v || w
+    f <- grepl("^FVAFR-.*$", sys_info[["nodename"]]) &&
+        sys_info[["effective_user"]] == "dominik.cullmann" &&
+        is_windows()
+    b <- grepl("^L-FVAFR-NB84223$", sys_info[["nodename"]]) &&
+        is_windows()
+
+    r <- switch(match.arg(type),
+                "cu" = h,
+                "fvafr" = v || f,
+                "bwi" = b,
+                "any" = ,
+                h || v || b || f)
     return(r)
 }
 
@@ -77,8 +87,8 @@ is_running_on_fvafrcu_machines <- function() {
 #' This check is an approximation only.
 #' @param verbose Be verbose?
 #' @template return_boolean
-#' @family logical helpers.
-#' @family test helpers.
+#' @family logical helpers
+#' @family test helpers
 #' @export
 #' @examples
 #' is_running_on_gitlab_com()
@@ -103,7 +113,7 @@ is_running_on_gitlab_com <- function(verbose = TRUE) {
 #' @param force Overwrite the variable if already set?
 #' @return The value RUN_R_TESTS is set to, \code{\link{NULL}} if nothing is
 #' done.
-#' @family test helpers.
+#' @family test helpers
 #' @export
 #' @examples
 #' set_run_r_tests(is_running_on_fvafrcu_machines())
@@ -126,9 +136,9 @@ set_run_r_tests  <- function(x, force = FALSE) {
 #' \code{\link{get_boolean_envvar}("RUN_R_TESTS")}.
 #'
 #' @inheritParams get_boolean_envvar
-#' @family test helpers.
-#' @family operating system functions.
-#' @family logical helpers.
+#' @family test helpers
+#' @family operating system functions
+#' @family logical helpers
 #' @return The value RUN_R_TESTS is set to, converted to boolean.
 #' \code{\link{FALSE}} if RUN_R_TESTS is not set or cannot be converted to
 #' boolean.
@@ -160,7 +170,7 @@ get_run_r_tests <- function(stop_on_failure = FALSE) {
 #' This should go into \code{\link{.onLoad}} to force tests on known hosts.
 #' @template return_invisibly_null
 #' @export
-#' @family test helpers.
+#' @family test helpers
 #' @inherit set_run_r_tests return
 #' @examples
 #' get_run_r_tests()
